@@ -1,7 +1,9 @@
 # -*- coding: UTF-8 -*-
+# 打包 python setup.py sdist
+# 上传 python setup.py sdist upload -r pypi 
 import json
 import requests
-class robot:
+class Robot:
     key = ''
     lanauage = 'zh'
     def __init__(self, key = '',lanauage = 'zh'):
@@ -19,4 +21,5 @@ class robot:
             return answer['data']['info']['text']
         else:
             return('英文服务尚未提供,敬请期待')
-            
\ No newline at end of file
+
+robot = Robot()
\ No newline at end of file
